==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/utils/e2_widget.h <==
/* $Id: e2_widget.h 762 2005-05-13 04:00:38Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file src/utils/e2_widget.h 
 * @brief miscelleanous GtkWidget utility function headers
 *
 * This file is the header file for the miscelleanous GtkWidget utility
 * functions.
 **/

#ifndef E2_WIDGET_H
#define E2_WIDGET_H

void e2_widget_set_tooltip (GtkTooltips *tooltips,
	GtkWidget *widget, gchar *text);
GtkWidget *e2_widget_get_icon (gchar *icon, GtkIconSize size);

GtkWidget *e2_widget_add_label (GtkWidget *box, gchar *text, gfloat align,
	gboolean exp, guint pad);
GtkWidget *_e2_widget_add_label (GtkWidget *box, gchar *text,
	gfloat xalign, gfloat yalign, gboolean exp, guint pad);

//FIXME: remove
#define add_entry(box, init_text, fill, pad) e2_widget_add_entry (box, init_text, fill, FALSE)
GtkWidget *e2_widget_add_entry (GtkWidget *box, gchar *init_text, gboolean exp,
	gboolean select_text);

//FIXME: remove
#define add_hbox(box, homogen, spacing, fill, pad) e2_widget_add_box (box, fill, pad, FALSE, homogen, spacing)
GtkWidget *e2_widget_get_box (gboolean vertical, gboolean homogen, gint spacing);
GtkWidget *e2_widget_add_box (GtkWidget *parent, gboolean exp, guint pad,
	gboolean vertical, gboolean homogen, gint spacing);

GtkWidget *e2_widget_add_sw (GtkWidget *box, GtkPolicyType h_policy,
	GtkPolicyType v_policy, gboolean exp, guint pad);
GtkWidget *e2_widget_get_sw (GtkPolicyType h_policy, GtkPolicyType v_policy);
GtkWidget *_e2_widget_get_sw (GtkPolicyType h_policy, GtkPolicyType v_policy,
	GtkShadowType shadow);
void e2_widget_sw_add_with_viewport (GtkWidget *sw, GtkWidget *child);
GtkWidget *e2_widget_add_notebook_page (GtkWidget *dialog,
	GtkWidget *notebook, gchar *name);

GtkWidget *add_separator(GtkWidget *box, gboolean exp, guint pad);
GtkWidget *add_table(GtkWidget *box, gint rows, gint cols, gboolean homogen,
	gboolean exp, guint pad);
GtkWidget *add_label_to_table(GtkWidget *table, gchar *text,
	gfloat align, gint left, gint right, gint top, gint bottom);
GtkWidget *add_entry_to_table(GtkWidget *table, gchar *init_text,
	gint left, gint right, gint top, gint bottom);
GtkWidget *add_button_to_table(GtkWidget *table, gchar *label,
	void *func, gpointer data, gint left, gint right, gint top, gint bottom);
GtkWidget *e2_button_add_toggle_to_table(GtkWidget *table, gchar *label,
	gint state, void *func, gpointer data, gint left, gint right, gint top,
	gint bottom);
GtkWidget *e2_button_add_radio_to_table (GtkWidget *table, gchar *label,
	GSList *group, gboolean state, void *func, gpointer data, gint left, 
	gint right, gint top, gint bottom);
GtkWidget *add_framed_table(GtkWidget *box, gchar *title, gint rows,
	gint cols, gboolean exp, guint pad);
GtkWidget *add_framed_widget(GtkWidget *box, gchar *title,
	GtkWidget *widget, gboolean exp, guint pad);
GtkWidget *e2_widget_add_frame (GtkWidget *box, gboolean fill, guint pad,
	gchar *title, gboolean strech);
void e2_widget_set_cursor(GdkCursorType type);
GtkWidget *e2_widget_add_eventbox (GtkWidget *box, gboolean fill, guint pad);
GtkWidget *e2_widget_get_notebook (gpointer func, gpointer data);
GtkWidget *e2_widget_add_notebook (GtkWidget *box, gboolean fill, guint pad,
	gpointer func, gpointer data);
void e2_widget_get_font_pixels (GtkWidget *widget, int *width, int *height);
void e2_widget_set_font (GtkWidget *widget, char *font_string, int *width,
	int *height);

#endif //ndef E2_WIDGET_H

==> emelfm2-0.1.7.tar.gz: emelfm2-0.1.7/src/utils/e2_widget.h <==
/* $Id: e2_widget.h 1856 2006-04-24 12:51:28Z tpgww $
 * 
 * Copyright (C) 2004-2006 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file src/utils/e2_widget.h 
 * @brief miscelleanous GtkWidget utility function headers
 *
 * This file is the header file for the miscelleanous GtkWidget utility
 * functions.
 **/

#ifndef E2_WIDGET_H
#define E2_WIDGET_H

void e2_widget_set_tooltip (GtkTooltips *tooltips,
	GtkWidget *widget, gchar *text);
void e2_widget_swap_tooltip (GtkWidget *widget);
GtkWidget *e2_widget_get_icon (gchar *icon, GtkIconSize size);

GtkWidget *e2_widget_add_label (GtkWidget *box, gchar *text, gfloat align,
	gboolean exp, guint pad);
GtkWidget *_e2_widget_add_label (GtkWidget *box, gchar *text,
	gfloat xalign, gfloat yalign, gboolean exp, guint pad);

//FIXME: remove
#define add_entry(box, init_text, fill, pad) e2_widget_add_entry (box, init_text, fill, FALSE)
GtkWidget *e2_widget_add_entry (GtkWidget *box, gchar *init_text, gboolean exp,
	gboolean select_text);

//FIXME: remove
#define add_hbox(box, homogen, spacing, fill, pad) e2_widget_add_box (box, fill, pad, FALSE, homogen, spacing)
GtkWidget *e2_widget_get_box (gboolean vertical, gboolean homogen, gint spacing);
GtkWidget *e2_widget_add_box (GtkWidget *parent, gboolean exp, guint pad,
	gboolean vertical, gboolean homogen, gint spacing);

GtkWidget *e2_widget_add_sw (GtkWidget *box, GtkPolicyType h_policy,
	GtkPolicyType v_policy, gboolean exp, guint pad);
GtkWidget *e2_widget_get_sw (GtkPolicyType h_policy, GtkPolicyType v_policy);
GtkWidget *_e2_widget_get_sw (GtkPolicyType h_policy, GtkPolicyType v_policy,
	GtkShadowType shadow);
void e2_widget_sw_add_with_viewport (GtkWidget *sw, GtkWidget *child);

GtkWidget *e2_widget_add_separator (GtkWidget *box, gboolean exp, guint pad);
GtkWidget *e2_widget_add_table (GtkWidget *box, gint rows, gint cols,
	gboolean homogen, gboolean exp, guint pad);
GtkWidget *e2_widget_add_label_to_table (GtkWidget *table, gchar *text,
	gfloat align, gint left, gint right, gint top, gint bottom);
//GtkWidget *e2_widget_add_entry_to_table (GtkWidget *table, gchar *init_text,
//	gint left, gint right, gint top, gint bottom);
//GtkWidget *e2_widget_add_framed_table (GtkWidget *box, gchar *title, gint rows,
//	gint cols, gboolean exp, guint pad);
//GtkWidget *e2_widget_add_framed_widget(GtkWidget *box, gchar *title,
//	GtkWidget *widget, gboolean exp, guint pad);
GtkWidget *e2_widget_add_frame (GtkWidget *box, gboolean fill, guint pad,
	gchar *title, gboolean strech);
void e2_widget_set_cursor(GdkCursorType type);
GtkWidget *e2_widget_add_eventbox (GtkWidget *box, gboolean fill, guint pad);
GtkWidget *e2_widget_get_notebook (gpointer func, gpointer data);
GtkWidget *e2_widget_add_notebook (GtkWidget *box, gboolean fill, guint pad,
	gpointer func, gpointer data);
GtkWidget *e2_widget_add_notebook_page (GtkWidget *dialog,
	GtkWidget *notebook, gchar *name);
void e2_widget_get_font_pixels (GtkWidget *widget, int *width, int *height);
void e2_widget_set_font (GtkWidget *widget, const gchar *font_string, int *width,
	int *height);

#endif //ndef E2_WIDGET_H
